==> ejc-ztpcdc-impl-3.0.0-20230531.020113-32-sources.jar: com/ejianc/business/basem/service/impl/AttachmentServiceImpl.java <==
package com.ejianc.business.basem.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.basem.utils.ToolUtil;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.basem.mapper.AttachmentMapper;
import com.ejianc.business.basem.bean.AttachmentEntity;
import com.ejianc.business.basem.service.IAttachmentService;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 附件
 * 
 * @author generator
 * 
 */
@Service("attachmentService")
@Transactional
public class AttachmentServiceImpl extends BaseServiceImpl<AttachmentMapper, AttachmentEntity> implements IAttachmentService{

    @Autowired
    private AttachmentMapper attachmentMapper;
    /**
     * 推送 附件
     * @param sourceBizId   来源业务主键
     * @param sourceBillType 单据类型
     * @param targetBizId 目标业务主键
     * @param targetBillType 目标单据类型
     * @return
     */
    public void attachmentFile(Long sourceBizId,String sourceBillType,Long targetBizId,String targetBillType){
        QueryWrapper<AttachmentEntity> where = new QueryWrapper<AttachmentEntity>();
        where.lambda()
                .eq(AttachmentEntity::getSourceId,sourceBizId)
                .eq(AttachmentEntity::getBillType,sourceBillType);
        List<AttachmentEntity> attachmentEntities = attachmentMapper.selectList(where);
        synchronized (AttachmentServiceImpl.class){
            Long attachmentMax = attachmentMapper.getAttachmentMax();
            if (ToolUtil.isNotEmpty(attachmentEntities)){
                if (null == attachmentMax){
                    attachmentMax = 0L;
                }
                List<AttachmentEntity> newAttachmentEntities = new ArrayList<>();
                for (int i = 0; i < attachmentEntities.size(); i++) {
                    attachmentMax ++ ;
                    AttachmentEntity e =  attachmentEntities.get(i);
                    AttachmentEntity newTemp = BeanMapper.map(e, AttachmentEntity.class);
                    newTemp.setId(attachmentMax);
                    newTemp.setSourceId(targetBizId);
                    newTemp.setBillType(targetBillType);
                    newTemp.setCreateTime(new Date());
                    newTemp.setUpdateTime(new Date());
                    newAttachmentEntities.add(newTemp);
                }
//                newAttachmentEntities.stream().forEach(System.out::println);
               saveBatch(newAttachmentEntities);

            }
        }
    }
}

==> ejc-ztpcdc-impl-3.0.0-20230608.013305-63-sources.jar: com/ejianc/business/basem/service/impl/AttachmentServiceImpl.java <==
package com.ejianc.business.basem.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ejianc.business.basem.utils.ToolUtil;
import com.ejianc.business.dc.vo.DcDrawrecycleInfoVO;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.basem.mapper.AttachmentMapper;
import com.ejianc.business.basem.bean.AttachmentEntity;
import com.ejianc.business.basem.service.IAttachmentService;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 附件
 * 
 * @author generator
 * 
 */
@Service("attachmentService")
@Transactional
public class AttachmentServiceImpl extends BaseServiceImpl<AttachmentMapper, AttachmentEntity> implements IAttachmentService{

    @Autowired
    private AttachmentMapper attachmentMapper;
    /**
     * 推送 附件
     * @param sourceBizId   来源业务主键
     * @param sourceBillType 单据类型
     * @param targetBizId 目标业务主键
     * @param targetBillType 目标单据类型
     * @return
     */
    public void attachmentFile(Long sourceBizId,String sourceBillType,Long targetBizId,String targetBillType){
        QueryWrapper<AttachmentEntity> where = new QueryWrapper<AttachmentEntity>();
        where.lambda()
                .eq(AttachmentEntity::getSourceId,sourceBizId)
                .eq(AttachmentEntity::getBillType,sourceBillType);
        List<AttachmentEntity> attachmentEntities = attachmentMapper.selectList(where);
        synchronized (AttachmentServiceImpl.class){
            Long attachmentMax = attachmentMapper.getAttachmentMax();
            if (ToolUtil.isNotEmpty(attachmentEntities)){
                if (null == attachmentMax){
                    attachmentMax = 0L;
                }
                List<AttachmentEntity> newAttachmentEntities = new ArrayList<>();
                for (int i = 0; i < attachmentEntities.size(); i++) {
                    attachmentMax ++ ;
                    AttachmentEntity e =  attachmentEntities.get(i);
                    AttachmentEntity newTemp = BeanMapper.map(e, AttachmentEntity.class);
                    newTemp.setId(attachmentMax);
                    newTemp.setSourceId(targetBizId);
                    newTemp.setBillType(targetBillType);
                    newTemp.setCreateTime(new Date());
                    newTemp.setUpdateTime(new Date());
                    newTemp.setSourceType("otherAttachment");
                    newAttachmentEntities.add(newTemp);
                }
//                newAttachmentEntities.stream().forEach(System.out::println);
               saveBatch(newAttachmentEntities);

            }
        }
    }

    @Override
    public void attachmentFileWithFileType(String sourceFileType, Long sourceBizId, String sourceBillType, String targetFileType,Long targetBizId, String targetBillType) {
        QueryWrapper<AttachmentEntity> where = new QueryWrapper<AttachmentEntity>();
        where.lambda()
                .eq(AttachmentEntity::getSourceId,sourceBizId)
                .eq(AttachmentEntity::getSourceType,sourceFileType)
                .eq(AttachmentEntity::getBillType,sourceBillType);
        List<AttachmentEntity> attachmentEntities = attachmentMapper.selectList(where);
        synchronized (AttachmentServiceImpl.class){
            Long attachmentMax = attachmentMapper.getAttachmentMax();
            if (ToolUtil.isNotEmpty(attachmentEntities)){
                if (null == attachmentMax){
                    attachmentMax = 0L;
                }
                List<AttachmentEntity> newAttachmentEntities = new ArrayList<>();
                for (int i = 0; i < attachmentEntities.size(); i++) {
                    attachmentMax ++ ;
                    AttachmentEntity e =  attachmentEntities.get(i);
                    AttachmentEntity newTemp = BeanMapper.map(e, AttachmentEntity.class);
                    newTemp.setId(attachmentMax);
                    newTemp.setSourceId(targetBizId);
                    newTemp.setBillType(targetBillType);
                    newTemp.setCreateTime(new Date());
                    newTemp.setUpdateTime(new Date());
                    newTemp.setSourceType(targetFileType);
                    newAttachmentEntities.add(newTemp);
                }
//                newAttachmentEntities.stream().forEach(System.out::println);
                saveBatch(newAttachmentEntities);

            }
        }
    }
}
